@@ -2,14 +2,16 @@
 
 /*
  * $Author: tom $
- * $Date: 2021/12/16 01:10:45 $
- * $Revision: 1.226 $
+ * $Date: 2025/01/14 21:32:41 $
+ * $Revision: 1.232 $
  */
 
 #define L_MARKER '<'
 #define R_MARKER '>'
 
-char *GPasteBuffer = 0;
+char *GPasteBuffer = NULL;
+
+static boolean usingMarkup = TRUE;
 
 /*
  * This beeps then flushes the stdout stream.
@@ -25,7 +27,7 @@ void Beep (void)
  */
 void cleanChar (char *s, int len, char character)
 {
-   if (s != 0)
+   if (s != NULL)
    {
       int x;
       for (x = 0; x < len; x++)
@@ -38,7 +40,7 @@ void cleanChar (char *s, int len, char character)
 
 void cleanChtype (chtype *s, int len, chtype character)
 {
-   if (s != 0)
+   if (s != NULL)
    {
       int x;
       for (x = 0; x < len; x++)
@@ -160,24 +162,24 @@ void freeChtype (chtype *string)
  */
 void freeCharList (char **list, unsigned size)
 {
-   if (list != 0)
+   if (list != NULL)
    {
       while (size-- != 0)
       {
 	 freeChar (list[size]);
-	 list[size] = 0;
+	 list[size] = NULL;
       }
    }
 }
 
 void freeChtypeList (chtype **list, unsigned size)
 {
-   if (list != 0)
+   if (list != NULL)
    {
       while (size-- != 0)
       {
 	 freeChtype (list[size]);
-	 list[size] = 0;
+	 list[size] = NULL;
       }
    }
 }
@@ -188,11 +190,11 @@ void freeChtypeList (chtype **list, unsigned size)
  */
 char *copyChar (const char *original)
 {
-   char *newstring = 0;
+   char *newstring = NULL;
 
-   if (original != 0)
+   if (original != NULL)
    {
-      if ((newstring = typeMallocN (char, strlen (original) + 1)) != 0)
+      if ((newstring = typeMallocN (char, strlen (original) + 1)) != NULL)
 	   strcpy (newstring, original);
    }
    return (newstring);
@@ -200,13 +202,13 @@ char *copyChar (const char *original)
 
 chtype *copyChtype (const chtype *original)
 {
-   chtype *newstring = 0;
+   chtype *newstring = NULL;
 
-   if (original != 0)
+   if (original != NULL)
    {
       int len = chlen (original);
 
-      if ((newstring = typeMallocN (chtype, len + 4)) != 0)
+      if ((newstring = typeMallocN (chtype, len + 4)) != NULL)
       {
 	 int x;
 
@@ -229,7 +231,7 @@ char **copyCharList (const char **list)
    size_t size = (size_t)lenCharList (list) + 1;
    char **result = typeMallocN (char *, size);
 
-   if (result != 0)
+   if (result != NULL)
    {
       unsigned n;
       for (n = 0; n < size; ++n)
@@ -243,7 +245,7 @@ chtype **copyChtypeList (const chtype **list)
    size_t size = (size_t)lenChtypeList (list) + 1;
    chtype **result = typeMallocN (chtype *, size);
 
-   if (result != 0)
+   if (result != NULL)
    {
       unsigned n;
       for (n = 0; n < size; ++n)
@@ -258,9 +260,9 @@ chtype **copyChtypeList (const chtype **list)
 int lenCharList (const char **list)
 {
    int result = 0;
-   if (list != 0)
+   if (list != NULL)
    {
-      while (*list++ != 0)
+      while (*list++ != NULL)
 	 ++result;
    }
    return result;
@@ -269,14 +271,54 @@ int lenCharList (const char **list)
 int lenChtypeList (const chtype **list)
 {
    int result = 0;
-   if (list != 0)
+   if (list != NULL)
    {
-      while (*list++ != 0)
+      while (*list++ != NULL)
 	 ++result;
    }
    return result;
 }
 
+int CDKchdir (const char *directory)
+{
+   int result;
+
+#ifdef HAVE_WORDEXP
+   wordexp_t expanded;
+   if (wordexp (directory, &expanded, WRDE_NOCMD) == 0)
+   {
+      if (expanded.we_wordc == 1 && strcmp (expanded.we_wordv[0], directory))
+	 result = chdir (expanded.we_wordv[0]);
+      else
+	 result = chdir (directory);
+      wordfree (&expanded);
+   }
+   else
+#endif
+      result = chdir (directory);
+   return result;
+}
+
+FILE *CDKopenFile (const char *filename, const char *mode)
+{
+   FILE *result;
+
+#ifdef HAVE_WORDEXP
+   wordexp_t expanded;
+   if (wordexp (filename, &expanded, WRDE_NOCMD) == 0)
+   {
+      if (expanded.we_wordc == 1 && strcmp (expanded.we_wordv[0], filename))
+	 result = fopen (expanded.we_wordv[0], mode);
+      else
+	 result = fopen (filename, mode);
+      wordfree (&expanded);
+   }
+   else
+#endif
+      result = fopen (filename, mode);
+   return result;
+}
+
 /*
  * This reads a file and sticks it into the char *** provided.
  */
@@ -288,12 +330,12 @@ int CDKreadFile (const char *filename, char ***array)
    unsigned used = 0;
 
    /* Can we open the file?  */
-   if ((fd = fopen (filename, "r")) == 0)
+   if ((fd = CDKopenFile (filename, "r")) == NULL)
    {
       return (-1);
    }
 
-   while ((fgets (temp, sizeof (temp), fd) != 0))
+   while ((fgets (temp, sizeof (temp), fd) != NULL))
    {
       size_t len = strlen (temp);
       if (len != 0 && temp[len - 1] == '\n')
@@ -349,7 +391,7 @@ static int encodeAttribute (const char *string, int from, chtype *mask)
 	 pair += DigitOf (string[++from]);
       }
 #ifdef HAVE_START_COLOR
-#define MAX_PAIR (int) (A_COLOR / (((~A_COLOR) << 1) & A_COLOR))
+#define MAX_PAIR (int) (A_COLOR / (((unsigned)(~A_COLOR) << 1) & A_COLOR))
       if (pair > MAX_PAIR)
 	 pair = MAX_PAIR;
       *mask = (chtype)COLOR_PAIR (pair);
@@ -386,7 +428,7 @@ static unsigned decodeAttribute (char *string,
    /* *INDENT-ON* */
 
    char temp[80];
-   char *result = (string != 0) ? (string + from) : temp;
+   char *result = (string != NULL) ? (string + from) : temp;
    char *base = result;
    chtype tmpattr = oldattr & A_ATTRIBUTES;
 
@@ -460,13 +502,13 @@ static unsigned decodeAttribute (char *string,
  */
 chtype *char2Chtype (const char *string, int *to, int *align)
 {
-   chtype *result = 0;
+   chtype *result = NULL;
    chtype mask;
 
    (*to) = 0;
    *align = LEFT;
 
-   if (string != 0 && *string != 0)
+   if (string != NULL && *string != 0)
    {
       int len = (int)strlen (string);
       int pass;
@@ -486,7 +528,7 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 
 	 if (pass != 0)
 	 {
-	    if ((result = typeMallocN (chtype, used + 2)) == 0)
+	    if ((result = typeMallocN (chtype, used + 2)) == NULL)
 	    {
 	       used = 0;
 	       break;
@@ -498,7 +540,7 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 	 used = 0;
 
 	 /* Look for an alignment marker.  */
-	 if (*string == L_MARKER)
+	 if (usingMarkup && (*string == L_MARKER))
 	 {
 	    if (string[1] == 'C' && string[2] == R_MARKER)
 	    {
@@ -517,7 +559,7 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 	    else if (string[1] == 'B' && string[2] == '=')
 	    {
 	       /* Set the item index value in the string.       */
-	       if (result != 0)
+	       if (result != NULL)
 	       {
 		  result[0] = ' ';
 		  result[1] = ' ';
@@ -527,7 +569,7 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 	       /* Pull out the bullet marker.  */
 	       while (string[x] != R_MARKER && string[x] != 0)
 	       {
-		  if (result != 0)
+		  if (result != NULL)
 		     result[x] = (chtype)string[x] | A_BOLD;
 		  x++;
 	       }
@@ -557,7 +599,7 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 
 	 while (adjust-- > 0)
 	 {
-	    if (result != 0)
+	    if (result != NULL)
 	       result[used] = ' ';
 	    used++;
 	 }
@@ -571,17 +613,20 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 	    /* Are we inside a format marker?  */
 	    if (!insideMarker)
 	    {
-	       if (string[from] == L_MARKER
+	       if (usingMarkup
+		   && string[from] == L_MARKER
 		   && (string[from + 1] == '/'
 		       || string[from + 1] == '!'
 		       || string[from + 1] == '#'))
 	       {
 		  insideMarker = TRUE;
 	       }
-	       else if (string[from] == '\\' && string[from + 1] == L_MARKER)
+	       else if (usingMarkup
+			&& string[from] == '\\'
+			&& string[from + 1] == L_MARKER)
 	       {
 		  from++;
-		  if (result != 0)
+		  if (result != NULL)
 		     result[used] = CharOf (string[from]) | attrib;
 		  used++;
 		  from++;
@@ -590,7 +635,7 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 	       {
 		  do
 		  {
-		     if (result != 0)
+		     if (result != NULL)
 			result[used] = ' ';
 		     used++;
 		  }
@@ -598,7 +643,7 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 	       }
 	       else
 	       {
-		  if (result != 0)
+		  if (result != NULL)
 		     result[used] = CharOf (string[from]) | attrib;
 		  used++;
 	       }
@@ -739,7 +784,7 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 		     }
 		     for (x = 0; x < adjust; x++)
 		     {
-			if (result != 0)
+			if (result != NULL)
 			   result[used] = lastChar | attrib;
 			used++;
 		     }
@@ -757,7 +802,7 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 	    }
 	 }
 
-	 if (result != 0)
+	 if (result != NULL)
 	 {
 	    result[used] = 0;
 	    result[used + 1] = 0;
@@ -768,7 +813,7 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 	  * the first character of the array.
 	  */
 	 if (used == 0
-	     && result != 0)
+	     && result != NULL)
 	 {
 	    result[0] = attrib;
 	 }
@@ -794,7 +839,7 @@ int chlen (const chtype *string)
 {
    int result = 0;
 
-   if (string != 0)
+   if (string != NULL)
    {
       while (string[result] != 0)
 	 result++;
@@ -849,13 +894,13 @@ void chstrncpy (char *dest, const chtype *src, int maxcount)
  */
 char *chtype2Char (const chtype *string)
 {
-   char *newstring = 0;
+   char *newstring = NULL;
 
-   if (string != 0)
+   if (string != NULL)
    {
       int len = chlen (string);
 
-      if ((newstring = typeMallocN (char, len + 1)) != 0)
+      if ((newstring = typeMallocN (char, len + 1)) != NULL)
       {
 	 int x;
 
@@ -875,9 +920,9 @@ char *chtype2Char (const chtype *string)
  */
 char *chtype2String (const chtype *string)
 {
-   char *newstring = 0;
+   char *newstring = NULL;
 
-   if (string != 0)
+   if (string != NULL)
    {
       int pass;
       int len = chlen (string);
@@ -894,7 +939,7 @@ char *chtype2String (const chtype *string)
 	    unsigned next = ((this_ch & 0xff) < 32) ? 5 : 1;
 
 	    need = decodeAttribute (newstring, need, last_ch, this_ch);
-	    if (newstring != 0)
+	    if (newstring != NULL)
 	    {
 	       if (next == 1)
 	       {
@@ -920,7 +965,7 @@ char *chtype2String (const chtype *string)
 	 ++need;
 	 if (!pass)
 	 {
-	    if ((newstring = typeCallocN (char, need)) == 0)
+	    if ((newstring = typeCallocN (char, need)) == NULL)
 	         break;
 	 }
       }
@@ -948,7 +993,7 @@ void stripWhiteSpace (EStripType stripType, char *string)
    size_t stringLength = 0;
 
    /* Make sure the string is not null.  */
-   if (string != 0
+   if (string != NULL
        && (stringLength = strlen (string)) != 0)
    {
       /* Strip leading whitespace */
@@ -999,13 +1044,13 @@ static unsigned countChar (const char *string, int separator)
  */
 char **CDKsplitString (const char *string, int separator)
 {
-   char **result = 0;
+   char **result = NULL;
    char *temp;
 
-   if (string != 0 && *string != 0)
+   if (string != NULL && *string != 0)
    {
       unsigned need = countChar (string, separator) + 2;
-      if ((result = typeMallocN (char *, need)) != 0)
+      if ((result = typeMallocN (char *, need)) != NULL)
       {
 	 unsigned item = 0;
 	 const char *first = string;
@@ -1015,7 +1060,7 @@ char **CDKsplitString (const char *string, int separator)
 	       string++;
 
 	    need = (unsigned)(string - first);
-	    if ((temp = typeMallocN (char, need + 1)) == 0)
+	    if ((temp = typeMallocN (char, need + 1)) == NULL)
 	         break;
 
 	    memcpy (temp, first, need);
@@ -1026,7 +1071,7 @@ char **CDKsplitString (const char *string, int separator)
 	       break;
 	    first = string;
 	 }
-	 result[item] = 0;
+	 result[item] = NULL;
       }
    }
    return result;
@@ -1045,7 +1090,7 @@ unsigned CDKallocStrings (char ***list, char *item, unsigned length, unsigned us
    if (need > used)
    {
       used = need;
-      if (*list == 0)
+      if (*list == NULL)
       {
 	 *list = typeMallocN (char *, used);
       }
@@ -1055,7 +1100,7 @@ unsigned CDKallocStrings (char ***list, char *item, unsigned length, unsigned us
       }
    }
    (*list)[length++] = copyChar (item);
-   (*list)[length] = 0;
+   (*list)[length] = NULL;
    return used;
 }
 
@@ -1065,9 +1110,9 @@ unsigned CDKallocStrings (char ***list, char *item, unsigned length, unsigned us
 unsigned CDKcountStrings (CDK_CSTRING2 list)
 {
    unsigned result = 0;
-   if (list != 0)
+   if (list != NULL)
    {
-      while (*list++ != 0)
+      while (*list++ != NULL)
 	 result++;
    }
    return result;
@@ -1078,10 +1123,10 @@ unsigned CDKcountStrings (CDK_CSTRING2 list)
  */
 void CDKfreeStrings (char **list)
 {
-   if (list != 0)
+   if (list != NULL)
    {
       void *base = (void *)list;
-      while (*list != 0)
+      while (*list != NULL)
 	 free (*list++);
       free (base);
    }
@@ -1092,10 +1137,10 @@ void CDKfreeStrings (char **list)
  */
 void CDKfreeChtypes (chtype **list)
 {
-   if (list != 0)
+   if (list != NULL)
    {
       void *base = (void *)list;
-      while (*list != 0)
+      while (*list != NULL)
       {
 	 freeChtype (*list++);
       }
@@ -1240,13 +1285,13 @@ int CDKgetDirectoryContents (const char *directory, char ***list)
    dp = opendir (directory);
 
    /* Could we open the directory?  */
-   if (dp == 0)
+   if (dp == NULL)
    {
       return -1;
    }
 
    /* Read the directory.  */
-   while ((dirStruct = readdir (dp)) != 0)
+   while ((dirStruct = readdir (dp)) != NULL)
    {
       if (strcmp (dirStruct->d_name, "."))
 	 used = CDKallocStrings (list, dirStruct->d_name,
@@ -1271,7 +1316,7 @@ int searchList (CDK_CSTRING2 list, int listSize, const char *pattern)
    int Index = -1;
 
    /* Make sure the pattern isn't null. */
-   if (pattern != 0)
+   if (pattern != NULL)
    {
       size_t len = strlen (pattern);
       int x;
@@ -1287,7 +1332,7 @@ int searchList (CDK_CSTRING2 list, int listSize, const char *pattern)
 	  * less than the provided word.  At this point we will set the index
 	  * to the current position.  If 'ret' is greater than 0, then the
 	  * current word is alphabetically greater than the given word.  We
-	  * should return with index, which might contain the last best match. 
+	  * should return with index, which might contain the last best match.
 	  * If they are equal, then we've found it.
 	  */
 	 if (ret < 0)
@@ -1314,14 +1359,17 @@ int checkForLink (const char *line, char *filename)
    int fPos = 0;
 
    /* Make sure the line isn't null. */
-   if (line == 0)
+   if (line == NULL)
    {
       return -1;
    }
    len = (int)strlen (line);
 
    /* Strip out the filename. */
-   if (line[0] == L_MARKER && line[1] == 'F' && line[2] == '=')
+   if (usingMarkup
+       && line[0] == L_MARKER
+       && line[1] == 'F'
+       && line[2] == '=')
    {
       int x = 3;
 
@@ -1347,11 +1395,11 @@ int checkForLink (const char *line, char *filename)
  */
 char *baseName (char *pathname)
 {
-   char *base = 0;
+   char *base = NULL;
 
-   if (pathname != 0
+   if (pathname != NULL
        && *pathname != '\0'
-       && (base = copyChar (pathname)) != 0)
+       && (base = copyChar (pathname)) != NULL)
    {
       size_t pathLen;
 
@@ -1379,12 +1427,12 @@ char *baseName (char *pathname)
  */
 char *dirName (char *pathname)
 {
-   char *dir = 0;
+   char *dir = NULL;
    size_t pathLen;
 
    /* Check if the string is null.  */
-   if (pathname != 0
-       && (dir = copyChar (pathname)) != 0
+   if (pathname != NULL
+       && (dir = copyChar (pathname)) != NULL
        && (pathLen = strlen (pathname)) != 0)
    {
       size_t x = pathLen;
@@ -1437,12 +1485,17 @@ int setWidgetDimension (int parentDim, int proposedDim, int adjustment)
    return dimension;
 }
 
+void enableCursesMarkup (boolean flag)
+{
+   usingMarkup = flag;
+}
+
 /*
  * This safely erases a given window.
  */
 void eraseCursesWindow (WINDOW *window)
 {
-   if (window != 0)
+   if (window != NULL)
    {
       werase (window);
       wrefresh (window);
@@ -1454,7 +1507,7 @@ void eraseCursesWindow (WINDOW *window)
  */
 void deleteCursesWindow (WINDOW *window)
 {
-   if (window != 0)
+   if (window != NULL)
    {
       eraseCursesWindow (window);
       delwin (window);
@@ -1463,20 +1516,24 @@ void deleteCursesWindow (WINDOW *window)
 
 /*
  * This moves a given window (if we're able to set the window's beginning).
- * We do not use mvwin(), because it does (usually) not move subwindows.
+ * We prefer to not use mvwin(), because SVr4 curses does not move subwindows.
  */
 void moveCursesWindow (WINDOW *window, int xdiff, int ydiff)
 {
-   if (window != 0)
+   if (window != NULL)
    {
       int xpos, ypos;
 
       getbegyx (window, ypos, xpos);
+#if defined(setbegyx)
       (void)setbegyx (window, (short)ypos, (short)xpos);
       xpos += xdiff;
       ypos += ydiff;
       werase (window);
       (void)setbegyx (window, (short)ypos, (short)xpos);
+#elif defined(HAVE_MVWIN)
+      (void)mvwin (window, (short)(ypos + ydiff), (short)(xpos + xdiff));
+#endif
       (void)ypos;
       (void)xpos;
    }
