@@ -1,4 +1,4 @@
-/* $Id: selection_ex.c,v 1.19 2012/03/22 00:01:42 tom Exp $ */
+/* $Id: selection_ex.c,v 1.22 2025/01/09 00:20:21 tom Exp $ */
 
 #include <cdk_test.h>
 
@@ -25,14 +25,11 @@ int main (int argc, char **argv)
       "-->"
    };
    /* *INDENT-EQLS* */
-   CDKSCREEN *cdkscreen    = 0;
-   CDKSELECTION *selection = 0;
-   WINDOW *cursesWin       = 0;
-   CDKLABEL *header        = 0;
-   CDKLABEL *footer        = 0;
+   CDKSCREEN *cdkscreen    = NULL;
+   CDKSELECTION *selection = NULL;
    const char *title       = "<C></5>Pick one or more accounts.";
-   char *title_string      = 0;
-   char **item             = 0;
+   char *title_string      = NULL;
+   char **item             = NULL;
    char temp[256];
    const char *mesg[200];
 #if defined (HAVE_PWD_H)
@@ -49,7 +46,7 @@ int main (int argc, char **argv)
    /* Use the account names to create a list. */
    count = 0;
 #if defined (HAVE_PWD_H)
-   while ((ent = getpwent ()) != 0)
+   while ((ent = getpwent ()) != NULL)
    {
       used = CDKallocStrings (&item, ent->pw_name, count++, used);
    }
@@ -57,43 +54,43 @@ int main (int argc, char **argv)
 #endif
    count--;
 
-   /* Set up CDK. */
-   cursesWin = initscr ();
-   cdkscreen = initCDKScreen (cursesWin);
+   cdkscreen = initCDKScreen (NULL);
 
    /* Set up CDK Colors. */
    initCDKColor ();
 
-   if ((title_string = CDKparamString2 (&params, 'h', 0)) != 0)
+   if ((title_string = CDKparamString2 (&params, 'h', NULL)) != NULL)
    {
       const char *list[2];
+      CDKLABEL *header;
 
       list[0] = title_string;
-      list[1] = 0;
+      list[1] = NULL;
       header = newCDKLabel (cdkscreen,
 			    CDKparamValue (&params, 'X', CENTER),
 			    CDKparamValue (&params, 'Y', TOP),
-			    (CDK_CSTRING2) list, 1,
+			    (CDK_CSTRING2)list, 1,
 			    CDKparamValue (&params, 'N', TRUE),
 			    CDKparamValue (&params, 'S', TRUE));
-      if (header != 0)
-	 activateCDKLabel (header, 0);
+      if (header != NULL)
+	 activateCDKLabel (header, NULL);
    }
 
-   if ((title_string = CDKparamString2 (&params, 'f', 0)) != 0)
+   if ((title_string = CDKparamString2 (&params, 'f', NULL)) != NULL)
    {
       const char *list[2];
+      CDKLABEL *footer;
 
       list[0] = title_string;
-      list[1] = 0;
+      list[1] = NULL;
       footer = newCDKLabel (cdkscreen,
 			    CDKparamValue (&params, 'X', CENTER),
 			    CDKparamValue (&params, 'Y', BOTTOM),
-			    (CDK_CSTRING2) list, 1,
+			    (CDK_CSTRING2)list, 1,
 			    CDKparamValue (&params, 'N', TRUE),
 			    CDKparamValue (&params, 'S', TRUE));
-      if (footer != 0)
-	 activateCDKLabel (footer, 0);
+      if (footer != NULL)
+	 activateCDKLabel (footer, NULL);
    }
    /* Create the selection list. */
    selection = newCDKSelection (cdkscreen,
@@ -105,18 +102,18 @@ int main (int argc, char **argv)
 				CDKparamValue (&params, 'W', 50),
 				CDKparamString2 (&params, 't', title),
 				(CDKparamNumber (&params, 'c')
-				 ? 0
-				 : (CDK_CSTRING2) item),
+				 ? NULL
+				 : (CDK_CSTRING2)item),
 				(CDKparamNumber (&params, 'c')
 				 ? 0
 				 : (int)count),
-				(CDK_CSTRING2) choices, 2,
+				(CDK_CSTRING2)choices, 2,
 				A_REVERSE,
 				CDKparamValue (&params, 'N', TRUE),
 				CDKparamValue (&params, 'S', FALSE));
 
    /* Is the selection list null? */
-   if (selection == 0)
+   if (selection == NULL)
    {
       /* Exit CDK. */
       destroyCDKScreen (cdkscreen);
@@ -129,11 +126,11 @@ int main (int argc, char **argv)
 
    if (CDKparamNumber (&params, 'c'))
    {
-      setCDKSelectionItems (selection, (CDK_CSTRING2) item, (int)count);
+      setCDKSelectionItems (selection, (CDK_CSTRING2)item, (int)count);
    }
 
    /* Activate the selection list. */
-   activateCDKSelection (selection, 0);
+   activateCDKSelection (selection, NULL);
 
    /* Check the exit status of the widget. */
    if (selection->exitType == vESCAPE_HIT)
@@ -141,7 +138,7 @@ int main (int argc, char **argv)
       mesg[0] = "<C>You hit escape. No items selected.";
       mesg[1] = "";
       mesg[2] = "<C>Press any key to continue.";
-      popupLabel (cdkscreen, (CDK_CSTRING2) mesg, 3);
+      popupLabel (cdkscreen, (CDK_CSTRING2)mesg, 3);
    }
    else if (selection->exitType == vNORMAL)
    {
@@ -155,7 +152,7 @@ int main (int argc, char **argv)
 	    mesg[y++] = copyChar (temp);
 	 }
       }
-      popupLabel (cdkscreen, (CDK_CSTRING2) mesg, (int)y);
+      popupLabel (cdkscreen, (CDK_CSTRING2)mesg, (int)y);
    }
 
    /* Clean up. */
