@@ -1,5 +1,5 @@
 /*
- * $Id: cdk_int.h,v 1.29 2021/08/25 23:34:40 tom Exp $
+ * $Id: cdk_int.h,v 1.32 2025/01/09 00:20:21 tom Exp $
  */
 
 #ifndef CDKINCLUDES
@@ -13,7 +13,7 @@ extern "C" {
 #include <cdk.h>
 
 /*
- * Copyright 2003-2016,2021 Thomas E. Dickey
+ * Copyright 2003-2024,2025 Thomas E. Dickey
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -39,6 +39,19 @@ extern "C" {
  * use or other dealings in this Software without prior written authorization.
  */
 
+#ifdef HAVE_WORDEXP
+#include <wordexp.h>
+#endif
+
+/* Solaris xpg4 curses uses these symbols; everyone else follows SVr4 */
+#if !defined(KEY_MIN) && defined(__KEY_MIN)
+#define KEY_MIN __KEY_MIN
+#endif
+
+#if !defined(KEY_MAX) && defined(__KEY_MAX)
+#define KEY_MAX __KEY_MAX
+#endif
+
 #define typeCallocN(type,n)     (type*)calloc((size_t)(n), sizeof(type))
 #define typeCalloc(type)        typeCallocN(type,1)
 
@@ -47,8 +60,8 @@ extern "C" {
 #define typeMallocN(type,n)     (type*)malloc((size_t)(n) * sizeof(type))
 #define typeMalloc(type)        typeMallocN(type,1)
 
-#define freeChecked(p)          if ((p) != 0) free (p)
-#define freeAndNull(p)          if ((p) != 0) { free (p); p = 0; }
+#define freeChecked(p)          if ((p) != NULL) free (p)
+#define freeAndNull(p)          if ((p) != NULL) { free (p); p = NULL; }
 
 #define isChar(c)               ((int)(c) >= 0 && (int)(c) < KEY_MIN)
 #define CharOf(c)               ((unsigned char)(c))
